@@ -3,9 +3,11 @@ Main interface for ssm service type definitions.
 
 Usage::
 
-    from mypy_boto3.ssm.type_defs import AccountSharingInfoTypeDef
+    ```python
+    from mypy_boto3_ssm.type_defs import AccountSharingInfoTypeDef
 
     data: AccountSharingInfoTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
